@@ -102,6 +102,7 @@ Document: TypeAlias = rest.Document
 Image: TypeAlias = rest.Image
 InferenceObject: TypeAlias = rest.InferenceObject
 StrictModeConfig: TypeAlias = rest.StrictModeConfig
+UpdateMode: TypeAlias = rest.UpdateMode
 
 QueryRequest: TypeAlias = rest.QueryRequest
 
@@ -127,6 +128,9 @@ ReplicaState: TypeAlias = rest.ReplicaState
 ClusterOperations: TypeAlias = rest.ClusterOperations
 ClusterStatus: TypeAlias = rest.ClusterStatus
 CollectionClusterInfo: TypeAlias = rest.CollectionClusterInfo
+OptimizationsResponse: TypeAlias = rest.OptimizationsResponse
+ShardKeysResponse: TypeAlias = rest.ShardKeysResponse
+DistributedTelemetryData: TypeAlias = rest.DistributedTelemetryData
 
 # we can't use `nptyping` package due to numpy/python-version incompatibilities
 # thus we need to define precise type annotations while we support python3.7
