@@ -65,7 +65,7 @@ class _CollectionsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse2006,
+            type_=m.InlineResponse2008,
             method="GET",
             url="/collections/{collection_name}/exists",
             headers=headers if headers else None,
@@ -94,7 +94,7 @@ class _CollectionsApi:
         if "Content-Type" not in headers:
             headers["Content-Type"] = "application/json"
         return self.api_client.request(
-            type_=m.InlineResponse200,
+            type_=m.InlineResponse2001,
             method="PUT",
             url="/collections/{collection_name}",
             headers=headers if headers else None,
@@ -121,7 +121,7 @@ class _CollectionsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse200,
+            type_=m.InlineResponse2001,
             method="DELETE",
             url="/collections/{collection_name}",
             headers=headers if headers else None,
@@ -142,7 +142,7 @@ class _CollectionsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse2004,
+            type_=m.InlineResponse2006,
             method="GET",
             url="/collections/{collection_name}",
             headers=headers if headers else None,
@@ -157,12 +157,41 @@ class _CollectionsApi:
         """
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse2003,
+            type_=m.InlineResponse2005,
             method="GET",
             url="/collections",
             headers=headers if headers else None,
         )
 
+    def _build_for_get_optimizations(
+        self,
+        collection_name: str,
+        _with: str = None,
+        completed_limit: int = None,
+    ):
+        """
+        Get progress of ongoing and completed optimizations for a collection
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+        }
+
+        query_params = {}
+        if _with is not None:
+            query_params["with"] = str(_with)
+        if completed_limit is not None:
+            query_params["completed_limit"] = str(completed_limit)
+
+        headers = {}
+        return self.api_client.request(
+            type_=m.InlineResponse20010,
+            method="GET",
+            url="/collections/{collection_name}/optimizations",
+            headers=headers if headers else None,
+            path_params=path_params,
+            params=query_params,
+        )
+
     def _build_for_update_collection(
         self,
         collection_name: str,
@@ -185,7 +214,7 @@ class _CollectionsApi:
         if "Content-Type" not in headers:
             headers["Content-Type"] = "application/json"
         return self.api_client.request(
-            type_=m.InlineResponse200,
+            type_=m.InlineResponse2001,
             method="PATCH",
             url="/collections/{collection_name}",
             headers=headers if headers else None,
@@ -199,7 +228,7 @@ class AsyncCollectionsApi(_CollectionsApi):
     async def collection_exists(
         self,
         collection_name: str,
-    ) -> m.InlineResponse2006:
+    ) -> m.InlineResponse2008:
         """
         Returns \"true\" if the given collection name exists, and \"false\" otherwise
         """
@@ -212,7 +241,7 @@ class AsyncCollectionsApi(_CollectionsApi):
         collection_name: str,
         timeout: int = None,
         create_collection: m.CreateCollection = None,
-    ) -> m.InlineResponse200:
+    ) -> m.InlineResponse2001:
         """
         Create new collection with given parameters
         """
@@ -226,7 +255,7 @@ class AsyncCollectionsApi(_CollectionsApi):
         self,
         collection_name: str,
         timeout: int = None,
-    ) -> m.InlineResponse200:
+    ) -> m.InlineResponse2001:
         """
         Drop collection and all associated data
         """
@@ -238,7 +267,7 @@ class AsyncCollectionsApi(_CollectionsApi):
     async def get_collection(
         self,
         collection_name: str,
-    ) -> m.InlineResponse2004:
+    ) -> m.InlineResponse2006:
         """
         Get detailed information about specified existing collection
         """
@@ -248,18 +277,33 @@ class AsyncCollectionsApi(_CollectionsApi):
 
     async def get_collections(
         self,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Get list name of all existing collections
         """
         return await self._build_for_get_collections()
 
+    async def get_optimizations(
+        self,
+        collection_name: str,
+        _with: str = None,
+        completed_limit: int = None,
+    ) -> m.InlineResponse20010:
+        """
+        Get progress of ongoing and completed optimizations for a collection
+        """
+        return await self._build_for_get_optimizations(
+            collection_name=collection_name,
+            _with=_with,
+            completed_limit=completed_limit,
+        )
+
     async def update_collection(
         self,
         collection_name: str,
         timeout: int = None,
         update_collection: m.UpdateCollection = None,
-    ) -> m.InlineResponse200:
+    ) -> m.InlineResponse2001:
         """
         Update parameters of the existing collection
         """
@@ -274,7 +318,7 @@ class SyncCollectionsApi(_CollectionsApi):
     def collection_exists(
         self,
         collection_name: str,
-    ) -> m.InlineResponse2006:
+    ) -> m.InlineResponse2008:
         """
         Returns \"true\" if the given collection name exists, and \"false\" otherwise
         """
@@ -287,7 +331,7 @@ class SyncCollectionsApi(_CollectionsApi):
         collection_name: str,
         timeout: int = None,
         create_collection: m.CreateCollection = None,
-    ) -> m.InlineResponse200:
+    ) -> m.InlineResponse2001:
         """
         Create new collection with given parameters
         """
@@ -301,7 +345,7 @@ class SyncCollectionsApi(_CollectionsApi):
         self,
         collection_name: str,
         timeout: int = None,
-    ) -> m.InlineResponse200:
+    ) -> m.InlineResponse2001:
         """
         Drop collection and all associated data
         """
@@ -313,7 +357,7 @@ class SyncCollectionsApi(_CollectionsApi):
     def get_collection(
         self,
         collection_name: str,
-    ) -> m.InlineResponse2004:
+    ) -> m.InlineResponse2006:
         """
         Get detailed information about specified existing collection
         """
@@ -323,18 +367,33 @@ class SyncCollectionsApi(_CollectionsApi):
 
     def get_collections(
         self,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Get list name of all existing collections
         """
         return self._build_for_get_collections()
 
+    def get_optimizations(
+        self,
+        collection_name: str,
+        _with: str = None,
+        completed_limit: int = None,
+    ) -> m.InlineResponse20010:
+        """
+        Get progress of ongoing and completed optimizations for a collection
+        """
+        return self._build_for_get_optimizations(
+            collection_name=collection_name,
+            _with=_with,
+            completed_limit=completed_limit,
+        )
+
     def update_collection(
         self,
         collection_name: str,
         timeout: int = None,
         update_collection: m.UpdateCollection = None,
-    ) -> m.InlineResponse200:
+    ) -> m.InlineResponse2001:
         """
         Update parameters of the existing collection
         """
