@@ -65,7 +65,7 @@ class _SnapshotsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse20011,
+            type_=m.InlineResponse20014,
             method="POST",
             url="/snapshots",
             headers=headers if headers else None,
@@ -92,7 +92,7 @@ class _SnapshotsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse20011,
+            type_=m.InlineResponse20014,
             method="POST",
             url="/collections/{collection_name}/shards/{shard_id}/snapshots",
             headers=headers if headers else None,
@@ -118,7 +118,7 @@ class _SnapshotsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse20011,
+            type_=m.InlineResponse20014,
             method="POST",
             url="/collections/{collection_name}/snapshots",
             headers=headers if headers else None,
@@ -144,7 +144,7 @@ class _SnapshotsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse2009,
+            type_=m.InlineResponse20012,
             method="DELETE",
             url="/snapshots/{snapshot_name}",
             headers=headers if headers else None,
@@ -174,7 +174,7 @@ class _SnapshotsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse2009,
+            type_=m.InlineResponse20012,
             method="DELETE",
             url="/collections/{collection_name}/shards/{shard_id}/snapshots/{snapshot_name}",
             headers=headers if headers else None,
@@ -202,7 +202,7 @@ class _SnapshotsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse2009,
+            type_=m.InlineResponse20012,
             method="DELETE",
             url="/collections/{collection_name}/snapshots/{snapshot_name}",
             headers=headers if headers else None,
@@ -284,7 +284,7 @@ class _SnapshotsApi:
         """
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse20010,
+            type_=m.InlineResponse20013,
             method="GET",
             url="/snapshots",
             headers=headers if headers else None,
@@ -305,7 +305,7 @@ class _SnapshotsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse20010,
+            type_=m.InlineResponse20013,
             method="GET",
             url="/collections/{collection_name}/shards/{shard_id}/snapshots",
             headers=headers if headers else None,
@@ -325,7 +325,7 @@ class _SnapshotsApi:
 
         headers = {}
         return self.api_client.request(
-            type_=m.InlineResponse20010,
+            type_=m.InlineResponse20013,
             method="GET",
             url="/collections/{collection_name}/snapshots",
             headers=headers if headers else None,
@@ -354,7 +354,7 @@ class _SnapshotsApi:
         if "Content-Type" not in headers:
             headers["Content-Type"] = "application/json"
         return self.api_client.request(
-            type_=m.InlineResponse2009,
+            type_=m.InlineResponse20012,
             method="PUT",
             url="/collections/{collection_name}/snapshots/recover",
             headers=headers if headers else None,
@@ -393,7 +393,7 @@ class _SnapshotsApi:
             files["snapshot"] = snapshot
 
         return self.api_client.request(
-            type_=m.InlineResponse2009,
+            type_=m.InlineResponse20012,
             method="POST",
             url="/collections/{collection_name}/snapshots/upload",
             headers=headers if headers else None,
@@ -427,7 +427,7 @@ class _SnapshotsApi:
         if "Content-Type" not in headers:
             headers["Content-Type"] = "application/json"
         return self.api_client.request(
-            type_=m.InlineResponse2009,
+            type_=m.InlineResponse20012,
             method="PUT",
             url="/collections/{collection_name}/shards/{shard_id}/snapshots/recover",
             headers=headers if headers else None,
@@ -468,7 +468,7 @@ class _SnapshotsApi:
             files["snapshot"] = snapshot
 
         return self.api_client.request(
-            type_=m.InlineResponse2009,
+            type_=m.InlineResponse20012,
             method="POST",
             url="/collections/{collection_name}/shards/{shard_id}/snapshots/upload",
             headers=headers if headers else None,
@@ -478,12 +478,34 @@ class _SnapshotsApi:
             files=files,
         )
 
+    def _build_for_stream_shard_snapshot(
+        self,
+        collection_name: str,
+        shard_id: int,
+    ):
+        """
+        Stream the current state of a shard as a snapshot file
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+            "shard_id": str(shard_id),
+        }
+
+        headers = {}
+        return self.api_client.request(
+            type_=file,
+            method="GET",
+            url="/collections/{collection_name}/shards/{shard_id}/snapshot",
+            headers=headers if headers else None,
+            path_params=path_params,
+        )
+
 
 class AsyncSnapshotsApi(_SnapshotsApi):
     async def create_full_snapshot(
         self,
         wait: bool = None,
-    ) -> m.InlineResponse20011:
+    ) -> m.InlineResponse20014:
         """
         Create new snapshot of the whole storage
         """
@@ -496,7 +518,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         collection_name: str,
         shard_id: int,
         wait: bool = None,
-    ) -> m.InlineResponse20011:
+    ) -> m.InlineResponse20014:
         """
         Create new snapshot of a shard for a collection
         """
@@ -510,7 +532,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         self,
         collection_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse20011:
+    ) -> m.InlineResponse20014:
         """
         Create new snapshot for a collection
         """
@@ -523,7 +545,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         self,
         snapshot_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Delete snapshot of the whole storage
         """
@@ -538,7 +560,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         shard_id: int,
         snapshot_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Delete snapshot of a shard for a collection
         """
@@ -554,7 +576,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         collection_name: str,
         snapshot_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Delete snapshot for a collection
         """
@@ -605,7 +627,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
 
     async def list_full_snapshots(
         self,
-    ) -> m.InlineResponse20010:
+    ) -> m.InlineResponse20013:
         """
         Get list of snapshots of the whole storage
         """
@@ -615,7 +637,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         self,
         collection_name: str,
         shard_id: int,
-    ) -> m.InlineResponse20010:
+    ) -> m.InlineResponse20013:
         """
         Get list of snapshots for a shard of a collection
         """
@@ -627,7 +649,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
     async def list_snapshots(
         self,
         collection_name: str,
-    ) -> m.InlineResponse20010:
+    ) -> m.InlineResponse20013:
         """
         Get list of snapshots for a collection
         """
@@ -640,7 +662,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         collection_name: str,
         wait: bool = None,
         snapshot_recover: m.SnapshotRecover = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Recover local collection data from a snapshot. This will overwrite any data, stored on this node, for the collection. If collection does not exist - it will be created.
         """
@@ -657,7 +679,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         priority: SnapshotPriority = None,
         checksum: str = None,
         snapshot: IO[Any] = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Recover local collection data from an uploaded snapshot. This will overwrite any data, stored on this node, for the collection. If collection does not exist - it will be created.
         """
@@ -675,7 +697,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         shard_id: int,
         wait: bool = None,
         shard_snapshot_recover: m.ShardSnapshotRecover = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Recover shard of a local collection data from a snapshot. This will overwrite any data, stored in this shard, for the collection.
         """
@@ -694,7 +716,7 @@ class AsyncSnapshotsApi(_SnapshotsApi):
         priority: SnapshotPriority = None,
         checksum: str = None,
         snapshot: IO[Any] = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Recover shard of a local collection from an uploaded snapshot. This will overwrite any data, stored on this node, for the collection shard.
         """
@@ -707,12 +729,25 @@ class AsyncSnapshotsApi(_SnapshotsApi):
             snapshot=snapshot,
         )
 
+    async def stream_shard_snapshot(
+        self,
+        collection_name: str,
+        shard_id: int,
+    ) -> file:
+        """
+        Stream the current state of a shard as a snapshot file
+        """
+        return await self._build_for_stream_shard_snapshot(
+            collection_name=collection_name,
+            shard_id=shard_id,
+        )
+
 
 class SyncSnapshotsApi(_SnapshotsApi):
     def create_full_snapshot(
         self,
         wait: bool = None,
-    ) -> m.InlineResponse20011:
+    ) -> m.InlineResponse20014:
         """
         Create new snapshot of the whole storage
         """
@@ -725,7 +760,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         collection_name: str,
         shard_id: int,
         wait: bool = None,
-    ) -> m.InlineResponse20011:
+    ) -> m.InlineResponse20014:
         """
         Create new snapshot of a shard for a collection
         """
@@ -739,7 +774,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         self,
         collection_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse20011:
+    ) -> m.InlineResponse20014:
         """
         Create new snapshot for a collection
         """
@@ -752,7 +787,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         self,
         snapshot_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Delete snapshot of the whole storage
         """
@@ -767,7 +802,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         shard_id: int,
         snapshot_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Delete snapshot of a shard for a collection
         """
@@ -783,7 +818,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         collection_name: str,
         snapshot_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Delete snapshot for a collection
         """
@@ -834,7 +869,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
 
     def list_full_snapshots(
         self,
-    ) -> m.InlineResponse20010:
+    ) -> m.InlineResponse20013:
         """
         Get list of snapshots of the whole storage
         """
@@ -844,7 +879,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         self,
         collection_name: str,
         shard_id: int,
-    ) -> m.InlineResponse20010:
+    ) -> m.InlineResponse20013:
         """
         Get list of snapshots for a shard of a collection
         """
@@ -856,7 +891,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
     def list_snapshots(
         self,
         collection_name: str,
-    ) -> m.InlineResponse20010:
+    ) -> m.InlineResponse20013:
         """
         Get list of snapshots for a collection
         """
@@ -869,7 +904,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         collection_name: str,
         wait: bool = None,
         snapshot_recover: m.SnapshotRecover = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Recover local collection data from a snapshot. This will overwrite any data, stored on this node, for the collection. If collection does not exist - it will be created.
         """
@@ -886,7 +921,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         priority: SnapshotPriority = None,
         checksum: str = None,
         snapshot: IO[Any] = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Recover local collection data from an uploaded snapshot. This will overwrite any data, stored on this node, for the collection. If collection does not exist - it will be created.
         """
@@ -904,7 +939,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         shard_id: int,
         wait: bool = None,
         shard_snapshot_recover: m.ShardSnapshotRecover = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Recover shard of a local collection data from a snapshot. This will overwrite any data, stored in this shard, for the collection.
         """
@@ -923,7 +958,7 @@ class SyncSnapshotsApi(_SnapshotsApi):
         priority: SnapshotPriority = None,
         checksum: str = None,
         snapshot: IO[Any] = None,
-    ) -> m.InlineResponse2009:
+    ) -> m.InlineResponse20012:
         """
         Recover shard of a local collection from an uploaded snapshot. This will overwrite any data, stored on this node, for the collection shard.
         """
@@ -935,3 +970,16 @@ class SyncSnapshotsApi(_SnapshotsApi):
             checksum=checksum,
             snapshot=snapshot,
         )
+
+    def stream_shard_snapshot(
+        self,
+        collection_name: str,
+        shard_id: int,
+    ) -> file:
+        """
+        Stream the current state of a shard as a snapshot file
+        """
+        return self._build_for_stream_shard_snapshot(
+            collection_name=collection_name,
+            shard_id=shard_id,
+        )
