@@ -1,5 +1,6 @@
 from enum import Enum
 from typing import TypeAlias
+from itertools import permutations
 
 import numpy as np
 
@@ -9,6 +10,8 @@ from qdrant_client.http import models
 EPSILON = 1.1920929e-7  # https://doc.rust-lang.org/std/f32/constant.EPSILON.html
 # https://github.com/qdrant/qdrant/blob/7164ac4a5987d28f1c93f5712aef8e09e7d93555/lib/segment/src/spaces/simple_avx.rs#L99C10-L99C10
 
+NAIVE_FEEDBACK_CONFIDENCE_MARGIN = 0.0
+
 
 class DistanceOrder(str, Enum):
     BIGGER_IS_BETTER = "bigger_is_better"
@@ -57,7 +60,46 @@ class ContextQuery:
         self.context_pairs = context_pairs
 
 
-DenseQueryVector: TypeAlias = DiscoveryQuery | ContextQuery | RecoQuery
+class FeedbackItem:
+    def __init__(self, vector: list[float], score: float):
+        self.vector = np.array(vector)
+        self.score = score
+        assert not np.isnan(self.vector).any(), "Feedback vector must not contain NaN"
+
+
+class NaiveFeedbackCoefficients:
+    def __init__(self, a: float, b: float, c: float):
+        self.a = a
+        self.b = b
+        self.c = c
+
+
+class FeedbackContextPair:
+    def __init__(
+        self, positive: types.NumpyArray, negative: types.NumpyArray, partial_computation: float
+    ):
+        self.positive = positive
+        self.negative = negative
+        self.partial_computation = partial_computation
+
+
+class NaiveFeedbackQuery:
+    def __init__(
+        self,
+        target: list[float],
+        feedback: list[FeedbackItem],
+        coefficients: NaiveFeedbackCoefficients,
+    ):
+        self.target = np.array(target)
+        self.feedback = feedback
+        self.coefficients = coefficients
+
+        assert not np.isnan(self.target).any(), "Target vector must not contain NaN"
+        for item in self.feedback:
+            assert not np.isnan(item.vector).any(), "Feedback vector must not contain NaN"
+
+
+DenseQueryVector: TypeAlias = DiscoveryQuery | ContextQuery | RecoQuery | NaiveFeedbackQuery
 
 
 def distance_to_order(distance: models.Distance) -> DistanceOrder:
@@ -296,3 +338,36 @@ def calculate_context_scores(
         overall_scores += pair_scores
 
     return overall_scores
+
+
+def calculate_naive_feedback_query(
+    query: NaiveFeedbackQuery, vectors: types.NumpyArray, distance_type: models.Distance
+) -> types.NumpyArray:
+    context_pairs: list[FeedbackContextPair] = []
+    if len(query.feedback) >= 2:
+        for p in permutations(query.feedback, 2):
+            positive_item, negative_item = p[0], p[1]
+            confidence = positive_item.score - negative_item.score
+
+            if confidence <= NAIVE_FEEDBACK_CONFIDENCE_MARGIN:
+                continue
+
+            partial_computation = (confidence**query.coefficients.b) * query.coefficients.c
+            context_pairs.append(
+                FeedbackContextPair(
+                    positive=positive_item.vector,
+                    negative=negative_item.vector,
+                    partial_computation=partial_computation,
+                )
+            )
+
+    score = query.coefficients.a * calculate_distance_core(query.target, vectors, distance_type)
+
+    for pair in context_pairs:
+        sim_pos = calculate_distance_core(pair.positive, vectors, distance_type)
+        sim_neg = calculate_distance_core(pair.negative, vectors, distance_type)
+        delta = sim_pos - sim_neg
+
+        score += pair.partial_computation * delta
+
+    return score
